@@ -4,75 +4,69 @@ package format
 const (
 	ALL = "all"
 
-	PROBE       = "probe"
 	IMAGE       = "image"
+	LINK_FRAME  = "link_frame"
+	PROBE       = "probe"
 	TCP_STREAM  = "tcp_stream"
 	UDP_PAYLOAD = "udp_payload"
-	LINK_FRAME  = "link_frame"
-
-	RAW  = "raw"
-	JSON = "json"
-	BSON = "bson"
-
-	DNS                = "dns"
-	DNS_TCP            = "dns_tcp"
-	ETHER8023_FRAME    = "ether8023_frame"
-	BSD_LOOPBACK_FRAME = "bsd_loopback_frame"
-	SLL_PACKET         = "sll_packet"
-	SLL2_PACKET        = "sll2_packet"
-	IPV4_PACKET        = "ipv4_packet"
-	UDP_DATAGRAM       = "udp_datagram"
-	TCP_SEGMENT        = "tcp_segment"
-	ICMP               = "icmp"
-
-	ELF = "elf"
-	AR  = "ar"
 
 	AAC_FRAME           = "aac_frame"
 	ADTS                = "adts"
 	ADTS_FRAME          = "adts_frame"
 	APEV2               = "apev2"
+	AR                  = "ar"
 	AV1_CCR             = "av1_ccr"
 	AV1_FRAME           = "av1_frame"
 	AV1_OBU             = "av1_obu"
+	AVC_ANNEXB          = "avc_annexb"
+	AVC_AU              = "avc_au"
+	AVC_DCR             = "avc_dcr"
+	AVC_NALU            = "avc_nalu"
+	AVC_PPS             = "avc_pps"
+	AVC_SEI             = "avc_sei"
+	AVC_SPS             = "avc_sps"
+	BENCODE             = "bencode"
+	BSD_LOOPBACK_FRAME  = "bsd_loopback_frame"
+	BSON                = "bson"
 	BZIP2               = "bzip2"
+	CBOR                = "cbor"
+	DNS                 = "dns"
+	DNS_TCP             = "dns_tcp"
+	ELF                 = "elf"
+	ETHER8023_FRAME     = "ether8023_frame"
 	EXIF                = "exif"
 	FLAC                = "flac"
 	FLAC_FRAME          = "flac_frame"
 	FLAC_METADATABLOCK  = "flac_metadatablock"
 	FLAC_METADATABLOCKS = "flac_metadatablocks"
-	FLAC_STREAMINFO     = "flac_streaminfo"
 	FLAC_PICTURE        = "flac_picture"
+	FLAC_STREAMINFO     = "flac_streaminfo"
 	FLV                 = "flv" // TODO:
 	GIF                 = "gif"
 	GZIP                = "gzip"
+	HEVC_ANNEXB         = "hevc_annexb"
+	HEVC_AU             = "hevc_au"
+	HEVC_DCR            = "hevc_dcr"
+	HEVC_NALU           = "hevc_nalu"
 	ICC_PROFILE         = "icc_profile"
+	ICMP                = "icmp"
 	ID3V1               = "id3v1"
 	ID3V11              = "id3v11"
 	ID3V2               = "id3v2"
+	IPV4_PACKET         = "ipv4_packet"
 	JPEG                = "jpeg"
+	JSON                = "json"
 	MATROSKA            = "matroska"
 	MP3                 = "mp3"
 	MP3_FRAME           = "mp3_frame"
-	XING                = "xing"
 	MP4                 = "mp4"
 	MPEG_ASC            = "mpeg_asc"
-	AVC_ANNEXB          = "avc_annexb"
-	AVC_DCR             = "avc_dcr"
-	AVC_SPS             = "avc_sps"
-	AVC_PPS             = "avc_pps"
-	AVC_SEI             = "avc_sei"
-	AVC_NALU            = "avc_nalu"
-	AVC_AU              = "avc_au"
-	HEVC_ANNEXB         = "hevc_annexb"
-	HEVC_AU             = "hevc_au"
-	HEVC_NALU           = "hevc_nalu"
-	HEVC_DCR            = "hevc_dcr"
 	MPEG_ES             = "mpeg_es"
 	MPEG_PES            = "mpeg_pes"
 	MPEG_PES_PACKET     = "mpeg_pes_packet"
 	MPEG_SPU            = "mpeg_spu"
 	MPEG_TS             = "mpeg_ts"
+	MSGPACK             = "msgpack"
 	OGG                 = "ogg"
 	OGG_PAGE            = "ogg_page"
 	OPUS_PACKET         = "opus_packet"
@@ -82,16 +76,22 @@ const (
 	PROTOBUF            = "protobuf"
 	PROTOBUF_WIDEVINE   = "protobuf_widevine"
 	PSSH_PLAYREADY      = "pssh_playready"
+	RAW                 = "raw"
+	SLL_PACKET          = "sll_packet"
+	SLL2_PACKET         = "sll2_packet"
 	TAR                 = "tar"
+	TCP_SEGMENT         = "tcp_segment"
 	TIFF                = "tiff"
+	UDP_DATAGRAM        = "udp_datagram"
 	VORBIS_COMMENT      = "vorbis_comment"
 	VORBIS_PACKET       = "vorbis_packet"
 	VP8_FRAME           = "vp8_frame"
-	VP9_FRAME           = "vp9_frame"
 	VP9_CFM             = "vp9_cfm"
+	VP9_FRAME           = "vp9_frame"
 	VPX_CCR             = "vpx_ccr"
 	WAV                 = "wav"
 	WEBP                = "webp"
+	XING                = "xing"
 	ZIP                 = "zip"
 )
 
