@@ -425,7 +425,7 @@ func ParseCases(s string) *Case {
 
 	// TODO: better section splitter, too much heuristics now
 	for _, section := range SectionParser(regexp.MustCompile(
-		`^\$ .*$|^stdin:$|^stderr:$|^exitcode:.*$|^#.*$|^/.*:|^[^<:|]+>.*$`,
+		`^\$ .*$|^stdin:$|^stderr:$|^exitcode:.*$|^#.*$|^/.*:|^[^<|"]+>.*$`,
 	), s) {
 		n, v := section.Name, section.Value
 
