@@ -6,6 +6,7 @@ import (
 	"fmt"
 	"io"
 	"io/ioutil"
+	"math/big"
 
 	"github.com/wader/fq/internal/recoverfn"
 	"github.com/wader/fq/pkg/bitio"
@@ -636,6 +637,10 @@ func (d *D) FieldValueS(name string, a int64, sms ...scalar.Mapper) {
 	d.FieldScalarFn(name, func(_ scalar.S) (scalar.S, error) { return scalar.S{Actual: a}, nil }, sms...)
 }
 
+func (d *D) FieldValueBigInt(name string, a *big.Int, sms ...scalar.Mapper) {
+	d.FieldScalarFn(name, func(_ scalar.S) (scalar.S, error) { return scalar.S{Actual: a}, nil }, sms...)
+}
+
 func (d *D) FieldValueBool(name string, a bool, sms ...scalar.Mapper) {
 	d.FieldScalarFn(name, func(_ scalar.S) (scalar.S, error) { return scalar.S{Actual: a}, nil }, sms...)
 }
@@ -648,6 +653,10 @@ func (d *D) FieldValueStr(name string, a string, sms ...scalar.Mapper) {
 	d.FieldScalarFn(name, func(_ scalar.S) (scalar.S, error) { return scalar.S{Actual: a}, nil }, sms...)
 }
 
+func (d *D) FieldValueNil(name string, sms ...scalar.Mapper) {
+	d.FieldScalarFn(name, func(_ scalar.S) (scalar.S, error) { return scalar.S{Actual: nil}, nil }, sms...)
+}
+
 func (d *D) FieldValueRaw(name string, a []byte, sms ...scalar.Mapper) {
 	d.FieldScalarFn(name, func(_ scalar.S) (scalar.S, error) {
 		return scalar.S{Actual: bitio.NewBufferFromBytes(a, -1)}, nil
@@ -848,7 +857,7 @@ func (d *D) FieldFormatBitBuf(name string, bb *bitio.Buffer, group Group, inArg
 	return dv, v
 }
 
-// TODO: rethink this
+// TODO: rethink these
 func (d *D) FieldRootBitBuf(name string, bb *bitio.Buffer) *Value {
 	v := &Value{}
 	v.V = &scalar.S{Actual: bb}
@@ -861,6 +870,17 @@ func (d *D) FieldRootBitBuf(name string, bb *bitio.Buffer) *Value {
 	return v
 }
 
+func (d *D) FieldArrayRootBitBufFn(name string, bb *bitio.Buffer, fn func(d *D)) *Value {
+	cd := d.FieldDecoder(name, bb, &Compound{IsArray: true})
+	cd.Value.IsRoot = true
+	d.AddChild(cd.Value)
+	fn(cd)
+
+	cd.Value.postProcess()
+
+	return cd.Value
+}
+
 func (d *D) FieldStructRootBitBufFn(name string, bb *bitio.Buffer, fn func(d *D)) *Value {
 	cd := d.FieldDecoder(name, bb, &Compound{})
 	cd.Value.IsRoot = true
