@@ -75,6 +75,7 @@ func (i *Interp) _registry(c interface{}, a []interface{}) interface{} {
 			"probe_order": f.ProbeOrder,
 			"root_name":   f.RootName,
 			"root_array":  f.RootArray,
+			"to_repr":     f.ToRepr,
 		}
 
 		var dependenciesVs []interface{}
@@ -336,6 +337,11 @@ func makeDecodeValue(dv *decode.Value) interface{} {
 				JQValue:         gojqextra.Null{},
 				decodeValueBase: decodeValueBase{dv},
 			}
+		case *big.Int:
+			return decodeValue{
+				JQValue:         gojqextra.Number{V: vv},
+				decodeValueBase: decodeValueBase{dv},
+			}
 		default:
 			panic(fmt.Sprintf("unreachable vv %#+v", vv))
 		}
